@@ -39,8 +39,8 @@ use crate::{Api,
      AddstudentResponse,
      DeleteStudentResponse,
      UpdateStudentResponse,
-     GetAllstudentsResponse,
-     GetStudentByIdResponse
+     GetStudentByIdResponse,
+     GetStudentsResponse
      };
 
 /// Convert input into a base path, e.g. "http://example:123". Also checks the scheme as it goes.
@@ -715,135 +715,6 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
-    async fn get_allstudents(
-        &self,
-        param_first_name: Option<String>,
-        param_middle_name: Option<String>,
-        param_last_name: Option<String>,
-        param_offset: Option<i32>,
-        param_count: Option<i32>,
-        context: &C) -> Result<GetAllstudentsResponse, ApiError>
-    {
-        let mut client_service = self.client_service.clone();
-        let mut uri = format!(
-            "{}/query-api/student-service/students",
-            self.base_path
-        );
-
-        // Query parameters
-        let query_string = {
-            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
-            if let Some(param_first_name) = param_first_name {
-                query_string.append_pair("firstName",
-                    &param_first_name.to_string());
-            }
-            if let Some(param_middle_name) = param_middle_name {
-                query_string.append_pair("middleName",
-                    &param_middle_name.to_string());
-            }
-            if let Some(param_last_name) = param_last_name {
-                query_string.append_pair("lastName",
-                    &param_last_name.to_string());
-            }
-            if let Some(param_offset) = param_offset {
-                query_string.append_pair("offset",
-                    &param_offset.to_string());
-            }
-            if let Some(param_count) = param_count {
-                query_string.append_pair("count",
-                    &param_count.to_string());
-            }
-            query_string.finish()
-        };
-        if !query_string.is_empty() {
-            uri += "?";
-            uri += &query_string;
-        }
-
-        let uri = match Uri::from_str(&uri) {
-            Ok(uri) => uri,
-            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
-        };
-
-        let mut request = match Request::builder()
-            .method("GET")
-            .uri(uri)
-            .body(Body::empty()) {
-                Ok(req) => req,
-                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
-        };
-
-        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
-        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
-            Ok(h) => h,
-            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
-        });
-
-        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
-            // Currently only authentication with Basic and Bearer are supported
-            match auth_data {
-                &AuthData::Bearer(ref bearer_header) => {
-                    let auth = swagger::auth::Header(bearer_header.clone());
-                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
-                        Ok(h) => h,
-                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
-                    };
-                    request.headers_mut().insert(
-                        hyper::header::AUTHORIZATION,
-                        header);
-                },
-                _ => {}
-            }
-        }
-
-        let mut response = client_service.call((request, context.clone()))
-            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
-
-        match response.status().as_u16() {
-            200 => {
-                let body = response.into_body();
-                let body = body
-                        .to_raw()
-                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
-                let body = str::from_utf8(&body)
-                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
-                let body = serde_json::from_str::<models::StudentCollection>(body)?;
-                Ok(GetAllstudentsResponse::SuccessfulOperation
-                    (body)
-                )
-            }
-            400 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllstudentsResponse::InvalidIDSupplied
-                )
-            }
-            404 => {
-                let body = response.into_body();
-                Ok(
-                    GetAllstudentsResponse::StudentNotFound
-                )
-            }
-            code => {
-                let headers = response.headers().clone();
-                let body = response.into_body()
-                       .take(100)
-                       .to_raw().await;
-                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
-                    code,
-                    headers,
-                    match body {
-                        Ok(body) => match String::from_utf8(body) {
-                            Ok(body) => body,
-                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
-                        },
-                        Err(e) => format!("<Failed to read body: {}>", e),
-                    }
-                )))
-            }
-        }
-    }
-
     async fn get_student_by_id(
         &self,
         param_id: uuid::Uuid,
@@ -950,4 +821,153 @@ impl<S, C> Api<C> for Client<S, C> where
         }
     }
 
+    async fn get_students(
+        &self,
+        param_name: Option<String>,
+        param_email: Option<String>,
+        param_phone: Option<String>,
+        param_undergraduate_school: Option<String>,
+        param_date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
+        param_place_of_birth: Option<String>,
+        param_sorts: Option<&Vec<models::StudentSortCriteria>>,
+        param_offset: Option<i32>,
+        param_count: Option<i32>,
+        context: &C) -> Result<GetStudentsResponse, ApiError>
+    {
+        let mut client_service = self.client_service.clone();
+        let mut uri = format!(
+            "{}/query-api/student-service/students",
+            self.base_path
+        );
+
+        // Query parameters
+        let query_string = {
+            let mut query_string = form_urlencoded::Serializer::new("".to_owned());
+            if let Some(param_name) = param_name {
+                query_string.append_pair("name",
+                    &param_name.to_string());
+            }
+            if let Some(param_email) = param_email {
+                query_string.append_pair("email",
+                    &param_email.to_string());
+            }
+            if let Some(param_phone) = param_phone {
+                query_string.append_pair("phone",
+                    &param_phone.to_string());
+            }
+            if let Some(param_undergraduate_school) = param_undergraduate_school {
+                query_string.append_pair("undergraduateSchool",
+                    &param_undergraduate_school.to_string());
+            }
+            if let Some(param_date_of_birth) = param_date_of_birth {
+                query_string.append_pair("dateOfBirth",
+                    &param_date_of_birth.to_string());
+            }
+            if let Some(param_place_of_birth) = param_place_of_birth {
+                query_string.append_pair("placeOfBirth",
+                    &param_place_of_birth.to_string());
+            }
+            if let Some(param_sorts) = param_sorts {
+                query_string.append_pair("sorts",
+                    &param_sorts.iter().map(ToString::to_string).collect::<Vec<String>>().join(","));
+            }
+            if let Some(param_offset) = param_offset {
+                query_string.append_pair("offset",
+                    &param_offset.to_string());
+            }
+            if let Some(param_count) = param_count {
+                query_string.append_pair("count",
+                    &param_count.to_string());
+            }
+            query_string.finish()
+        };
+        if !query_string.is_empty() {
+            uri += "?";
+            uri += &query_string;
+        }
+
+        let uri = match Uri::from_str(&uri) {
+            Ok(uri) => uri,
+            Err(err) => return Err(ApiError(format!("Unable to build URI: {}", err))),
+        };
+
+        let mut request = match Request::builder()
+            .method("GET")
+            .uri(uri)
+            .body(Body::empty()) {
+                Ok(req) => req,
+                Err(e) => return Err(ApiError(format!("Unable to create request: {}", e)))
+        };
+
+        let header = HeaderValue::from_str(Has::<XSpanIdString>::get(context).0.clone().to_string().as_str());
+        request.headers_mut().insert(HeaderName::from_static("x-span-id"), match header {
+            Ok(h) => h,
+            Err(e) => return Err(ApiError(format!("Unable to create X-Span ID header value: {}", e)))
+        });
+
+        if let Some(auth_data) = Has::<Option<AuthData>>::get(context).as_ref() {
+            // Currently only authentication with Basic and Bearer are supported
+            match auth_data {
+                &AuthData::Bearer(ref bearer_header) => {
+                    let auth = swagger::auth::Header(bearer_header.clone());
+                    let header = match HeaderValue::from_str(&format!("{}", auth)) {
+                        Ok(h) => h,
+                        Err(e) => return Err(ApiError(format!("Unable to create Authorization header: {}", e)))
+                    };
+                    request.headers_mut().insert(
+                        hyper::header::AUTHORIZATION,
+                        header);
+                },
+                _ => {}
+            }
+        }
+
+        let mut response = client_service.call((request, context.clone()))
+            .map_err(|e| ApiError(format!("No response received: {}", e))).await?;
+
+        match response.status().as_u16() {
+            200 => {
+                let body = response.into_body();
+                let body = body
+                        .to_raw()
+                        .map_err(|e| ApiError(format!("Failed to read response: {}", e))).await?;
+                let body = str::from_utf8(&body)
+                    .map_err(|e| ApiError(format!("Response was not valid UTF8: {}", e)))?;
+                let body = serde_json::from_str::<models::StudentViewCollection>(body)?;
+                Ok(GetStudentsResponse::SuccessfulOperation
+                    (body)
+                )
+            }
+            400 => {
+                let body = response.into_body();
+                Ok(
+                    GetStudentsResponse::InvalidIDSupplied
+                )
+            }
+            404 => {
+                let body = response.into_body();
+                Ok(
+                    GetStudentsResponse::StudentNotFound
+                )
+            }
+            code => {
+                let headers = response.headers().clone();
+                let body = response.into_body()
+                       .take(100)
+                       .to_raw().await;
+                Err(ApiError(format!("Unexpected response code {}:\n{:?}\n\n{}",
+                    code,
+                    headers,
+                    match body {
+                        Ok(body) => match String::from_utf8(body) {
+                            Ok(body) => body,
+                            Err(e) => format!("<Body was not UTF8: {:?}>", e),
+                        },
+                        Err(e) => format!("<Failed to read body: {}>", e),
+                    }
+                )))
+            }
+        }
+    }
+
 }
