@@ -25,8 +25,8 @@ use crate::{Api,
      AddstudentResponse,
      DeleteStudentResponse,
      UpdateStudentResponse,
-     GetAllstudentsResponse,
-     GetStudentByIdResponse
+     GetStudentByIdResponse,
+     GetStudentsResponse
 };
 
 mod paths {
@@ -450,153 +450,6 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                         }
             },
 
-            // GetAllstudents - GET /query-api/student-service/students
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS) => {
-                {
-                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
-                        &Some(ref authorization) => authorization,
-                        &None => return Ok(Response::builder()
-                                                .status(StatusCode::FORBIDDEN)
-                                                .body(Body::from("Unauthenticated"))
-                                                .expect("Unable to create Authentication Forbidden response")),
-                    };
-                }
-
-                // Query parameters (note that non-required or collection query parameters will ignore garbage values, rather than causing a 400 response)
-                let query_params = form_urlencoded::parse(uri.query().unwrap_or_default().as_bytes()).collect::<Vec<_>>();
-                let param_first_name = query_params.iter().filter(|e| e.0 == "firstName").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_first_name = match param_first_name {
-                    Some(param_first_name) => {
-                        let param_first_name =
-                            <String as std::str::FromStr>::from_str
-                                (&param_first_name);
-                        match param_first_name {
-                            Ok(param_first_name) => Some(param_first_name),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter firstName - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter firstName")),
-                        }
-                    },
-                    None => None,
-                };
-                let param_middle_name = query_params.iter().filter(|e| e.0 == "middleName").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_middle_name = match param_middle_name {
-                    Some(param_middle_name) => {
-                        let param_middle_name =
-                            <String as std::str::FromStr>::from_str
-                                (&param_middle_name);
-                        match param_middle_name {
-                            Ok(param_middle_name) => Some(param_middle_name),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter middleName - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter middleName")),
-                        }
-                    },
-                    None => None,
-                };
-                let param_last_name = query_params.iter().filter(|e| e.0 == "lastName").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_last_name = match param_last_name {
-                    Some(param_last_name) => {
-                        let param_last_name =
-                            <String as std::str::FromStr>::from_str
-                                (&param_last_name);
-                        match param_last_name {
-                            Ok(param_last_name) => Some(param_last_name),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter lastName - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter lastName")),
-                        }
-                    },
-                    None => None,
-                };
-                let param_offset = query_params.iter().filter(|e| e.0 == "offset").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_offset = match param_offset {
-                    Some(param_offset) => {
-                        let param_offset =
-                            <i32 as std::str::FromStr>::from_str
-                                (&param_offset);
-                        match param_offset {
-                            Ok(param_offset) => Some(param_offset),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter offset - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter offset")),
-                        }
-                    },
-                    None => None,
-                };
-                let param_count = query_params.iter().filter(|e| e.0 == "count").map(|e| e.1.to_owned())
-                    .nth(0);
-                let param_count = match param_count {
-                    Some(param_count) => {
-                        let param_count =
-                            <i32 as std::str::FromStr>::from_str
-                                (&param_count);
-                        match param_count {
-                            Ok(param_count) => Some(param_count),
-                            Err(e) => return Ok(Response::builder()
-                                .status(StatusCode::BAD_REQUEST)
-                                .body(Body::from(format!("Couldn't parse query parameter count - doesn't match schema: {}", e)))
-                                .expect("Unable to create Bad Request response for invalid query parameter count")),
-                        }
-                    },
-                    None => None,
-                };
-
-                                let result = api_impl.get_allstudents(
-                                            param_first_name,
-                                            param_middle_name,
-                                            param_last_name,
-                                            param_offset,
-                                            param_count,
-                                        &context
-                                    ).await;
-                                let mut response = Response::new(Body::empty());
-                                response.headers_mut().insert(
-                                            HeaderName::from_static("x-span-id"),
-                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
-                                                .expect("Unable to create X-Span-ID header value"));
-
-                                        match result {
-                                            Ok(rsp) => match rsp {
-                                                GetAllstudentsResponse::SuccessfulOperation
-                                                    (body)
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
-                                                    response.headers_mut().insert(
-                                                        CONTENT_TYPE,
-                                                        HeaderValue::from_str("application/json")
-                                                            .expect("Unable to create Content-Type header for GET_ALLSTUDENTS_SUCCESSFUL_OPERATION"));
-                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
-                                                    *response.body_mut() = Body::from(body);
-                                                },
-                                                GetAllstudentsResponse::InvalidIDSupplied
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
-                                                },
-                                                GetAllstudentsResponse::StudentNotFound
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
-                                                },
-                                            },
-                                            Err(_) => {
-                                                // Application code returned an error. This should not happen, as the implementation should
-                                                // return a valid response.
-                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
-                                                *response.body_mut() = Body::from("An internal error occurred");
-                                            },
-                                        }
-
-                                        Ok(response)
-            },
-
             // GetStudentById - GET /query-api/student-service/students/{id}
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS_ID) => {
                 {
@@ -675,6 +528,216 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
+            // GetStudents - GET /query-api/student-service/students
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS) => {
+                {
+                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
+                        &Some(ref authorization) => authorization,
+                        &None => return Ok(Response::builder()
+                                                .status(StatusCode::FORBIDDEN)
+                                                .body(Body::from("Unauthenticated"))
+                                                .expect("Unable to create Authentication Forbidden response")),
+                    };
+                }
+
+                // Query parameters (note that non-required or collection query parameters will ignore garbage values, rather than causing a 400 response)
+                let query_params = form_urlencoded::parse(uri.query().unwrap_or_default().as_bytes()).collect::<Vec<_>>();
+                let param_name = query_params.iter().filter(|e| e.0 == "name").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_name = match param_name {
+                    Some(param_name) => {
+                        let param_name =
+                            <String as std::str::FromStr>::from_str
+                                (&param_name);
+                        match param_name {
+                            Ok(param_name) => Some(param_name),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter name - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter name")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_email = query_params.iter().filter(|e| e.0 == "email").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_email = match param_email {
+                    Some(param_email) => {
+                        let param_email =
+                            <String as std::str::FromStr>::from_str
+                                (&param_email);
+                        match param_email {
+                            Ok(param_email) => Some(param_email),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter email - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter email")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_phone = query_params.iter().filter(|e| e.0 == "phone").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_phone = match param_phone {
+                    Some(param_phone) => {
+                        let param_phone =
+                            <String as std::str::FromStr>::from_str
+                                (&param_phone);
+                        match param_phone {
+                            Ok(param_phone) => Some(param_phone),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter phone - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter phone")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_undergraduate_school = query_params.iter().filter(|e| e.0 == "undergraduateSchool").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_undergraduate_school = match param_undergraduate_school {
+                    Some(param_undergraduate_school) => {
+                        let param_undergraduate_school =
+                            <String as std::str::FromStr>::from_str
+                                (&param_undergraduate_school);
+                        match param_undergraduate_school {
+                            Ok(param_undergraduate_school) => Some(param_undergraduate_school),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter undergraduateSchool - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter undergraduateSchool")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_date_of_birth = query_params.iter().filter(|e| e.0 == "dateOfBirth").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_date_of_birth = match param_date_of_birth {
+                    Some(param_date_of_birth) => {
+                        let param_date_of_birth =
+                            <chrono::DateTime::<chrono::Utc> as std::str::FromStr>::from_str
+                                (&param_date_of_birth);
+                        match param_date_of_birth {
+                            Ok(param_date_of_birth) => Some(param_date_of_birth),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter dateOfBirth - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter dateOfBirth")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_place_of_birth = query_params.iter().filter(|e| e.0 == "placeOfBirth").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_place_of_birth = match param_place_of_birth {
+                    Some(param_place_of_birth) => {
+                        let param_place_of_birth =
+                            <String as std::str::FromStr>::from_str
+                                (&param_place_of_birth);
+                        match param_place_of_birth {
+                            Ok(param_place_of_birth) => Some(param_place_of_birth),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter placeOfBirth - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter placeOfBirth")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_sorts = query_params.iter().filter(|e| e.0 == "sorts").map(|e| e.1.to_owned())
+                    .filter_map(|param_sorts| param_sorts.parse().ok())
+                    .collect::<Vec<_>>();
+                let param_sorts = if !param_sorts.is_empty() {
+                    Some(param_sorts)
+                } else {
+                    None
+                };
+                let param_offset = query_params.iter().filter(|e| e.0 == "offset").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_offset = match param_offset {
+                    Some(param_offset) => {
+                        let param_offset =
+                            <i32 as std::str::FromStr>::from_str
+                                (&param_offset);
+                        match param_offset {
+                            Ok(param_offset) => Some(param_offset),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter offset - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter offset")),
+                        }
+                    },
+                    None => None,
+                };
+                let param_count = query_params.iter().filter(|e| e.0 == "count").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_count = match param_count {
+                    Some(param_count) => {
+                        let param_count =
+                            <i32 as std::str::FromStr>::from_str
+                                (&param_count);
+                        match param_count {
+                            Ok(param_count) => Some(param_count),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter count - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter count")),
+                        }
+                    },
+                    None => None,
+                };
+
+                                let result = api_impl.get_students(
+                                            param_name,
+                                            param_email,
+                                            param_phone,
+                                            param_undergraduate_school,
+                                            param_date_of_birth,
+                                            param_place_of_birth,
+                                            param_sorts.as_ref(),
+                                            param_offset,
+                                            param_count,
+                                        &context
+                                    ).await;
+                                let mut response = Response::new(Body::empty());
+                                response.headers_mut().insert(
+                                            HeaderName::from_static("x-span-id"),
+                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
+                                                .expect("Unable to create X-Span-ID header value"));
+
+                                        match result {
+                                            Ok(rsp) => match rsp {
+                                                GetStudentsResponse::SuccessfulOperation
+                                                    (body)
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
+                                                    response.headers_mut().insert(
+                                                        CONTENT_TYPE,
+                                                        HeaderValue::from_str("application/json")
+                                                            .expect("Unable to create Content-Type header for GET_STUDENTS_SUCCESSFUL_OPERATION"));
+                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
+                                                    *response.body_mut() = Body::from(body);
+                                                },
+                                                GetStudentsResponse::InvalidIDSupplied
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(400).expect("Unable to turn 400 into a StatusCode");
+                                                },
+                                                GetStudentsResponse::StudentNotFound
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(404).expect("Unable to turn 404 into a StatusCode");
+                                                },
+                                            },
+                                            Err(_) => {
+                                                // Application code returned an error. This should not happen, as the implementation should
+                                                // return a valid response.
+                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
+                                                *response.body_mut() = Body::from("An internal error occurred");
+                                            },
+                                        }
+
+                                        Ok(response)
+            },
+
             _ if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS) => method_not_allowed(),
             _ if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => method_not_allowed(),
             _ if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS) => method_not_allowed(),
@@ -698,10 +761,10 @@ impl<T> RequestParser<T> for ApiRequestParser {
             &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => Ok("DeleteStudent"),
             // UpdateStudent - PUT /mutation-api/student-service/students/{id}
             &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => Ok("UpdateStudent"),
-            // GetAllstudents - GET /query-api/student-service/students
-            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS) => Ok("GetAllstudents"),
             // GetStudentById - GET /query-api/student-service/students/{id}
             &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS_ID) => Ok("GetStudentById"),
+            // GetStudents - GET /query-api/student-service/students
+            &hyper::Method::GET if path.matched(paths::ID_QUERY_API_STUDENT_SERVICE_STUDENTS) => Ok("GetStudents"),
             _ => Err(()),
         }
     }
